#ifndef NT2_INCLUDE_CONSTANTS_FOUROPI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FOUROPI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/fouropi.hpp>

#endif
